package org.nanohttpd.protocols.http.response;

import com.lzy.okgo.model.HttpHeaders;
import com.lzy.okgo.model.Progress;
import java.io.BufferedWriter;
import java.io.ByteArrayInputStream;
import java.io.Closeable;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.io.PrintWriter;
import java.io.UnsupportedEncodingException;
import java.io.Writer;
import java.nio.charset.Charset;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.TimeZone;
import java.util.logging.Level;
import java.util.logging.Logger;
import java.util.zip.GZIPOutputStream;
import org.nanohttpd.protocols.http.NanoHTTPD;
import org.nanohttpd.protocols.http.content.ContentType;
import org.nanohttpd.protocols.http.request.Method;

public class Response implements Closeable {
    private boolean chunkedTransfer;
    private long contentLength;
    private List<String> cookieHeaders;
    private InputStream data;
    private GzipUsage gzipUsage = GzipUsage.DEFAULT;
    private final Map<String, String> header = new HashMap<String, String>() {
        /* class org.nanohttpd.protocols.http.response.Response.AnonymousClass1 */

        public String put(String str, String str2) {
            Response.this.lowerCaseHeader.put(str == null ? str : str.toLowerCase(), str2);
            return (String) super.put((Object) str, (Object) str2);
        }
    };
    private boolean keepAlive;
    private final Map<String, String> lowerCaseHeader = new HashMap();
    private String mimeType;
    private Method requestMethod;
    private IStatus status;

    /* access modifiers changed from: private */
    public enum GzipUsage {
        DEFAULT,
        ALWAYS,
        NEVER
    }

    protected Response(IStatus iStatus, String str, InputStream inputStream, long j) {
        this.status = iStatus;
        this.mimeType = str;
        boolean z = false;
        if (inputStream == null) {
            this.data = new ByteArrayInputStream(new byte[0]);
            this.contentLength = 0;
        } else {
            this.data = inputStream;
            this.contentLength = j;
        }
        this.chunkedTransfer = this.contentLength < 0 ? true : z;
        this.keepAlive = true;
        this.cookieHeaders = new ArrayList(10);
    }

    public static Response newChunkedResponse(IStatus iStatus, String str, InputStream inputStream) {
        return new Response(iStatus, str, inputStream, -1);
    }

    public static Response newFixedLengthResponse(IStatus iStatus, String str, byte[] bArr) {
        return newFixedLengthResponse(iStatus, str, new ByteArrayInputStream(bArr), (long) bArr.length);
    }

    private void sendBody(OutputStream outputStream, long j) throws IOException {
        long j2;
        byte[] bArr = new byte[((int) 16384)];
        boolean z = j == -1;
        while (true) {
            if (j > 0 || z) {
                if (z) {
                    j2 = 16384;
                } else {
                    j2 = Math.min(j, 16384L);
                }
                int read = this.data.read(bArr, 0, (int) j2);
                if (read > 0) {
                    try {
                        outputStream.write(bArr, 0, read);
                    } catch (Exception unused) {
                        if (this.data != null) {
                            this.data.close();
                        }
                    }
                    if (!z) {
                        j -= (long) read;
                    }
                } else {
                    return;
                }
            } else {
                return;
            }
        }
    }

    private void sendBodyWithCorrectEncoding(OutputStream outputStream, long j) throws IOException {
        if (useGzipWhenAccepted()) {
            GZIPOutputStream gZIPOutputStream = null;
            try {
                gZIPOutputStream = new GZIPOutputStream(outputStream);
            } catch (Exception unused) {
                InputStream inputStream = this.data;
                if (inputStream != null) {
                    inputStream.close();
                }
            }
            if (gZIPOutputStream != null) {
                sendBody(gZIPOutputStream, -1);
                gZIPOutputStream.finish();
                return;
            }
            return;
        }
        sendBody(outputStream, j);
    }

    private void sendBodyWithCorrectTransferAndEncoding(OutputStream outputStream, long j) throws IOException {
        if (this.requestMethod == Method.HEAD || !this.chunkedTransfer) {
            sendBodyWithCorrectEncoding(outputStream, j);
            return;
        }
        ChunkedOutputStream chunkedOutputStream = new ChunkedOutputStream(outputStream);
        sendBodyWithCorrectEncoding(chunkedOutputStream, -1);
        try {
            chunkedOutputStream.finish();
        } catch (Exception unused) {
            if (this.data != null) {
                this.data.close();
            }
        }
    }

    public void addCookieHeader(String str) {
        this.cookieHeaders.add(str);
    }

    public void addHeader(String str, String str2) {
        this.header.put(str, str2);
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable
    public void close() throws IOException {
        InputStream inputStream = this.data;
        if (inputStream != null) {
            inputStream.close();
        }
    }

    public void closeConnection(boolean z) {
        if (z) {
            this.header.put("connection", HttpHeaders.HEAD_VALUE_CONNECTION_CLOSE);
        } else {
            this.header.remove("connection");
        }
    }

    public List<String> getCookieHeaders() {
        return this.cookieHeaders;
    }

    public InputStream getData() {
        return this.data;
    }

    public String getHeader(String str) {
        return this.lowerCaseHeader.get(str.toLowerCase());
    }

    public String getMimeType() {
        return this.mimeType;
    }

    public Method getRequestMethod() {
        return this.requestMethod;
    }

    public IStatus getStatus() {
        return this.status;
    }

    public boolean isCloseConnection() {
        return HttpHeaders.HEAD_VALUE_CONNECTION_CLOSE.equals(getHeader("connection"));
    }

    /* access modifiers changed from: protected */
    public void printHeader(PrintWriter printWriter, String str, String str2) {
        printWriter.append((CharSequence) str).append(": ").append((CharSequence) str2).append("\r\n");
    }

    public void send(OutputStream outputStream) {
        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("E, d MMM yyyy HH:mm:ss 'GMT'", Locale.US);
        simpleDateFormat.setTimeZone(TimeZone.getTimeZone("GMT"));
        try {
            if (this.status != null) {
                PrintWriter printWriter = new PrintWriter((Writer) new BufferedWriter(new OutputStreamWriter(outputStream, new ContentType(this.mimeType).getEncoding())), false);
                printWriter.append("HTTP/1.1 ").append((CharSequence) this.status.getDescription()).append(" \r\n");
                String str = this.mimeType;
                if (str != null) {
                    printHeader(printWriter, HttpHeaders.HEAD_KEY_CONTENT_TYPE, str);
                }
                if (getHeader(Progress.DATE) == null) {
                    printHeader(printWriter, HttpHeaders.HEAD_KEY_DATE, simpleDateFormat.format(new Date()));
                }
                for (Map.Entry<String, String> entry : this.header.entrySet()) {
                    printHeader(printWriter, entry.getKey(), entry.getValue());
                }
                for (String str2 : this.cookieHeaders) {
                    printHeader(printWriter, HttpHeaders.HEAD_KEY_SET_COOKIE, str2);
                }
                if (getHeader("connection") == null) {
                    printHeader(printWriter, HttpHeaders.HEAD_KEY_CONNECTION, this.keepAlive ? HttpHeaders.HEAD_VALUE_CONNECTION_KEEP_ALIVE : HttpHeaders.HEAD_VALUE_CONNECTION_CLOSE);
                }
                if (getHeader("content-length") != null) {
                    setUseGzip(false);
                }
                if (useGzipWhenAccepted()) {
                    printHeader(printWriter, HttpHeaders.HEAD_KEY_CONTENT_ENCODING, "gzip");
                    setChunkedTransfer(true);
                }
                long j = this.data != null ? this.contentLength : 0;
                if (this.requestMethod != Method.HEAD && this.chunkedTransfer) {
                    printHeader(printWriter, "Transfer-Encoding", "chunked");
                } else if (!useGzipWhenAccepted()) {
                    j = sendContentLengthHeaderIfNotAlreadyPresent(printWriter, j);
                }
                printWriter.append("\r\n");
                printWriter.flush();
                sendBodyWithCorrectTransferAndEncoding(outputStream, j);
                outputStream.flush();
                NanoHTTPD.safeClose(this.data);
                return;
            }
            throw new Error("sendResponse(): Status can't be null.");
        } catch (IOException e2) {
            NanoHTTPD.LOG.log(Level.SEVERE, "Could not send response to the client", (Throwable) e2);
        }
    }

    /* access modifiers changed from: protected */
    public long sendContentLengthHeaderIfNotAlreadyPresent(PrintWriter printWriter, long j) {
        String header2 = getHeader("content-length");
        if (header2 != null) {
            try {
                return Long.parseLong(header2);
            } catch (NumberFormatException unused) {
                Logger logger = NanoHTTPD.LOG;
                logger.severe("content-length was no number " + header2);
                return j;
            }
        } else {
            printWriter.print("Content-Length: " + j + "\r\n");
            return j;
        }
    }

    public void setChunkedTransfer(boolean z) {
        this.chunkedTransfer = z;
    }

    public void setData(InputStream inputStream) {
        this.data = inputStream;
    }

    public void setKeepAlive(boolean z) {
        this.keepAlive = z;
    }

    public void setMimeType(String str) {
        this.mimeType = str;
    }

    public void setRequestMethod(Method method) {
        this.requestMethod = method;
    }

    public void setStatus(IStatus iStatus) {
        this.status = iStatus;
    }

    public Response setUseGzip(boolean z) {
        this.gzipUsage = z ? GzipUsage.ALWAYS : GzipUsage.NEVER;
        return this;
    }

    public boolean useGzipWhenAccepted() {
        GzipUsage gzipUsage2 = this.gzipUsage;
        if (gzipUsage2 == GzipUsage.DEFAULT) {
            if (getMimeType() == null || (!getMimeType().toLowerCase().contains("text/") && !getMimeType().toLowerCase().contains("/json"))) {
                return false;
            }
            return true;
        } else if (gzipUsage2 == GzipUsage.ALWAYS) {
            return true;
        } else {
            return false;
        }
    }

    public static Response newFixedLengthResponse(IStatus iStatus, String str, InputStream inputStream, long j) {
        return new Response(iStatus, str, inputStream, j);
    }

    public static Response newFixedLengthResponse(IStatus iStatus, String str, String str2) {
        byte[] bArr;
        ContentType contentType = new ContentType(str);
        if (str2 == null) {
            return newFixedLengthResponse(iStatus, str, new ByteArrayInputStream(new byte[0]), 0);
        }
        try {
            if (!Charset.forName(contentType.getEncoding()).newEncoder().canEncode(str2)) {
                contentType = contentType.tryUTF8();
            }
            bArr = str2.getBytes(contentType.getEncoding());
        } catch (UnsupportedEncodingException e2) {
            NanoHTTPD.LOG.log(Level.SEVERE, "encoding problem, responding nothing", (Throwable) e2);
            bArr = new byte[0];
        }
        return newFixedLengthResponse(iStatus, contentType.getContentTypeHeader(), new ByteArrayInputStream(bArr), (long) bArr.length);
    }

    public static Response newFixedLengthResponse(String str) {
        return newFixedLengthResponse(Status.OK, NanoHTTPD.MIME_HTML, str);
    }
}
